@@ -14,9 +14,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+
 def caches(cap, sources, srs_grids):
     caches = {}
-    for name, source in sources.iteritems():
+    for name, source in sources.items():
         conf = for_source(name, source, srs_grids)
         if not conf:
             continue
@@ -24,6 +25,7 @@ def caches(cap, sources, srs_grids):
 
     return caches
 
+
 def for_source(name, source, srs_grids):
     cache = {
         'sources': [name]
@@ -40,4 +42,3 @@ def for_source(name, source, srs_grids):
     cache['grids'] = grids
 
     return cache
-
