@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from mapproxy.compat.image import Image
+from PIL import Image
 from mapproxy.image import ImageSource
 from mapproxy.image.merge import concat_legends
 from mapproxy.test.image import is_png
