@@ -501,6 +501,49 @@ mapproxy_yaml_spec = {
             'inspire_md': type_spec('type', inspire_md),
             'versions': [str()],
         },
+        'ogcapi': {
+            'enable_tiles': bool(),
+            'enable_maps': bool(),
+            'map_srs': [str()],
+            'attribution': {
+                'text': str,
+            },
+            'on_source_errors': str(),
+            'max_output_pixels': one_of(number(), [number()]),
+            'image_formats': [str()],
+            'concurrent_layer_renderer': number(),
+            'md': {
+                'identification': {
+                    'title': str(),
+                    'description': str(),
+                    'url': str(),
+                    'terms_of_service': str(),
+                    'keywords': anything(),
+                },
+                'contact': {
+                    'name': str(),
+                    'email': str(),
+                    'address': str(),
+                    'city': str(),
+                    'stateorprovince': str(),
+                    'postalcode': str(),
+                    'country': str(),
+                    'phone': str(),
+                    'fax': str(),
+                    'url': str(),
+                    'instructions': str(),
+                },
+                'license': {
+                    required('name'): str(),
+                    'url': str(),
+                },
+                'provider': {
+                    'name': str(),
+                    'url': str(),
+                },
+            },
+            "default_dataset_layers": [str()],
+        }
     },
 
     'sources': {
@@ -594,6 +637,23 @@ mapproxy_yaml_spec = {
             }),
             'debug': {
             },
+            'ogcapitiles': combined(source_commons, {
+                required('landingpage_url'): str(),
+                'collection': str(),
+                'tile_matrix_set_id': str(),
+                'image': image_opts,
+            }),
+            'ogcapimaps': combined(source_commons, {
+                required('landingpage_url'): str(),
+                'collection': str(),
+                'supported_srs': [str()],
+                'transparent': bool(),
+                'image': combined(image_opts, {
+                    'transparent_color': one_of(str(), [number()]),
+                    'transparent_color_tolerance': number(),
+                }),
+                'bgcolor': one_of(str(), [number()]),
+            }),
         })
     },
 
@@ -621,7 +681,9 @@ mapproxy_yaml_spec = {
                     required('values'): [one_of(str, float, int)],
                     'default': one_of(str, float, int),
                 }
-            }
+            },
+            "nominal_res": number(),
+            "nominal_scale": number(),
         })])
     ),
     # `parts` can be used for partial configurations that are referenced
