@@ -247,6 +247,10 @@ class Request(object):
             scheme = self.environ['wsgi.url_scheme']
         return scheme
 
+    @cached_property
+    def accept_header(self):
+        return self.environ.get('HTTP_ACCEPT', '')
+
     @cached_property
     def host_url(self):
         return '%s://%s/' % (self.url_scheme, self.host)
