@@ -15,28 +15,22 @@
 
 from __future__ import print_function
 
+
+import re
 import threading
 import sys
-import cgi
 import socket
 import errno
 import time
 import base64
 from contextlib import contextmanager
+from urllib.parse import parse_qsl, urlsplit
+
 from mapproxy.util.py import reraise
-from mapproxy.compat import iteritems, PY2
-from mapproxy.compat.modules import urlparse
-if PY2:
-    from cStringIO import StringIO
-else:
-    from io import StringIO
+from http.server import HTTPServer as HTTPServer_, BaseHTTPRequestHandler
 
-if PY2:
-    from BaseHTTPServer import HTTPServer as HTTPServer_, BaseHTTPRequestHandler
-else:
-    from http.server import HTTPServer as HTTPServer_, BaseHTTPRequestHandler
 
-class RequestsMissmatchError(AssertionError):
+class RequestsMismatchError(AssertionError):
     def __init__(self, assertions):
         self.assertions = assertions
 
@@ -44,11 +38,13 @@ class RequestsMissmatchError(AssertionError):
         assertions = []
         for assertion in self.assertions:
             assertions.append(text_indent(str(assertion), '    ', ' -  '))
-        return 'requests missmatch:\n' + '\n'.join(assertions)
+        return 'requests mismatch:\n' + '\n'.join(assertions)
+
 
 class RequestError(str):
     pass
 
+
 def text_indent(text, indent, first_indent=None):
     if first_indent is None:
         first_indent = indent
@@ -56,16 +52,18 @@ def text_indent(text, indent, first_indent=None):
     text = first_indent + text
     return text.replace('\n', '\n' + indent)
 
-class RequestMissmatch(object):
+
+class RequestMismatch(object):
     def __init__(self, msg, expected, actual):
         self.msg = msg
         self.expected = expected
         self.actual = actual
 
     def __str__(self):
-        return ('requests missmatch, expected:\n' +
-            text_indent(str(self.expected), '    ') +
-            '\n  got:\n' + text_indent(str(self.actual), '    '))
+        return ('requests mismatch (%s), expected:\n' % self.msg +
+                text_indent(str(self.expected), '    ') +
+                '\n  got:\n' + text_indent(str(self.actual), '    '))
+
 
 class HTTPServer(HTTPServer_):
     allow_reuse_address = True
@@ -78,6 +76,7 @@ class HTTPServer(HTTPServer_):
                 return
         HTTPServer_.handle_error(self, request, client_address)
 
+
 class ThreadedStopableHTTPServer(threading.Thread):
     def __init__(self, address, requests_responses, unordered=False, query_comparator=None):
         threading.Thread.__init__(self, **{'group': None})
@@ -85,8 +84,8 @@ class ThreadedStopableHTTPServer(threading.Thread):
         self.daemon = True
         self.sucess = False
         self.shutdown = False
-        self.httpd = HTTPServer(address,mock_http_handler(requests_responses,
-            unordered=unordered, query_comparator=query_comparator))
+        self.httpd = HTTPServer(address, mock_http_handler(requests_responses,
+                                                           unordered=unordered, query_comparator=query_comparator))
         self.httpd.timeout = 1.0
         self.assertions = self.httpd.assertions = []
 
@@ -96,7 +95,8 @@ class ThreadedStopableHTTPServer(threading.Thread):
 
     def run(self):
         while self.requests_responses:
-            if self.shutdown: break
+            if self.shutdown:
+                break
             self.httpd.handle_request()
         if self.requests_responses:
             missing_req = [req for req, resp in self.requests_responses]
@@ -108,6 +108,7 @@ class ThreadedStopableHTTPServer(threading.Thread):
         # force socket close so next test can bind to same address
         self.httpd.socket.close()
 
+
 class ThreadedSingleRequestHTTPServer(threading.Thread):
     def __init__(self, address, request_handler):
         threading.Thread.__init__(self, **{'group': None})
@@ -129,7 +130,12 @@ class ThreadedSingleRequestHTTPServer(threading.Thread):
 def mock_http_handler(requests_responses, unordered=False, query_comparator=None):
     if query_comparator is None:
         query_comparator = query_eq
+
     class MockHTTPHandler(BaseHTTPRequestHandler):
+        def do_HEAD(self):
+            self.query_data = self.path
+            return self.do_mock_request('HEAD')
+
         def do_GET(self):
             self.query_data = self.path
             return self.do_mock_request('GET')
@@ -162,12 +168,12 @@ def mock_http_handler(requests_responses, unordered=False, query_comparator=None
             if 'method' in req:
                 if req['method'] != method:
                     self.server.assertions.append(
-                        RequestMissmatch('unexpected method', req['method'], method)
+                        RequestMismatch('unexpected method', req['method'], method)
                     )
                     self.server.shutdown = True
             if req.get('require_basic_auth', False):
                 if 'Authorization' not in self.headers:
-                    requests_responses.insert(0, (req, resp)) # push back
+                    requests_responses.insert(0, (req, resp))  # push back
                     self.send_response(401)
                     self.send_header('WWW-Authenticate', 'Basic realm="Secure Area"')
                     self.end_headers()
@@ -177,20 +183,21 @@ def mock_http_handler(requests_responses, unordered=False, query_comparator=None
                 for k, v in req['headers'].items():
                     if k not in self.headers:
                         self.server.assertions.append(
-                            RequestMissmatch('missing header', k, self.headers)
+                            RequestMismatch('missing header', k, self.headers)
                         )
                     elif self.headers[k] != v:
                         self.server.assertions.append(
-                            RequestMissmatch('header missmatch', '%s: %s' % (k, v), self.headers)
+                            RequestMismatch('header mismatch', '%s: %s' % (k, v), self.headers)
                         )
             if not query_comparator(req['path'], self.query_data):
                 self.server.assertions.append(
-                    RequestMissmatch('requests differ', req['path'], self.query_data)
+                    RequestMismatch('requests differ', req['path'], self.query_data)
                 )
                 query_actual = set(query_to_dict(self.query_data).items())
                 query_expected = set(query_to_dict(req['path']).items())
                 self.server.assertions.append(
-                    RequestMissmatch('requests params differ', query_actual - query_expected, query_expected - query_actual)
+                    RequestMismatch('requests params differ', query_expected -
+                                    query_actual, query_actual - query_expected)
                 )
                 self.server.shutdown = True
             if 'req_assert_function' in req:
@@ -206,21 +213,27 @@ def mock_http_handler(requests_responses, unordered=False, query_comparator=None
                 with open(resp['body_file'], 'rb') as f:
                     self.wfile.write(f.read())
             else:
-                self.wfile.write(resp['body'])
+                if 'body' in resp:
+                    self.wfile.write(resp['body'])
+                else:
+                    self.wfile.write(b'')
             if not requests_responses:
                 self.server.shutdown = True
             return
+
         def start_response(self, resp):
             self.send_response(int(resp.get('status', '200')))
             if 'headers' in resp:
-                for key, value in iteritems(resp['headers']):
+                for key, value in resp['headers'].items():
                     self.send_header(key, value)
             self.end_headers()
+
         def log_request(self, code, size=None):
             pass
 
     return MockHTTPHandler
 
+
 class MockServ(object):
     def __init__(self, port=0, host='localhost', unordered=False, bbox_aware_query_comparator=False):
         self._requested_port = port
@@ -235,7 +248,7 @@ class MockServ(object):
 
     def _init_thread(self):
         self._thread = ThreadedStopableHTTPServer((self.host, self._requested_port),
-            [], unordered=self.unordered, query_comparator=self.query_comparator)
+                                                  [], unordered=self.unordered, query_comparator=self.query_comparator)
         if self._requested_port == 0:
             self.port = self._thread.http_port
         self.address = (self.host, self.port)
@@ -267,15 +280,16 @@ class MockServ(object):
 
     def __exit__(self, type, value, traceback):
         self._thread.shutdown = True
-        self._thread.join()
+        self._thread.join(30)
 
         if not self._thread.sucess and value:
             print('requests to mock httpd did not '
-            'match expectations:\n %s' % RequestsMissmatchError(self._thread.assertions))
+                  'match expectations:\n %s' % RequestsMismatchError(self._thread.assertions))
         if value:
             raise reraise((type, value, traceback))
         if not self._thread.sucess:
-            raise RequestsMissmatchError(self._thread.assertions)
+            raise RequestsMismatchError(self._thread.assertions)
+
 
 def wms_query_eq(expected, actual):
     """
@@ -290,7 +304,7 @@ def wms_query_eq(expected, actual):
     >>> wms_query_eq('/1/2/3.png', '/1/2/0.png')
     False
     """
-    from mapproxy.srs import bbox_equals
+    from mapproxy.util.bbox import bbox_equals
     if path_from_query(expected) != path_from_query(actual):
         return False
 
@@ -312,6 +326,10 @@ def wms_query_eq(expected, actual):
 
     return True
 
+
+numbers_only = re.compile(r'^-?\d+\.\d+(,-?\d+\.\d+)*$')
+
+
 def query_eq(expected, actual):
     """
     >>> query_eq('bAR=baz&foo=bizz', 'foO=bizz&bar=baz')
@@ -322,11 +340,60 @@ def query_eq(expected, actual):
     True
     >>> query_eq('/1/2/3.png', '/1/2/0.png')
     False
+    >>> query_eq('/map?point=2.9999999999,1.00000000001', '/map?point=3.0,1.0')
+    True
     """
-    return (query_to_dict(expected) == query_to_dict(actual) and
-            path_from_query(expected) == path_from_query(actual))
 
-def assert_query_eq(expected, actual):
+    if path_from_query(expected) != path_from_query(actual):
+        return False
+
+    expected = query_to_dict(expected)
+    actual = query_to_dict(actual)
+
+    if set(expected.keys()) != set(actual.keys()):
+        return False
+
+    for ke, ve in expected.items():
+        if numbers_only.match(ve):
+            if not float_string_almost_eq(ve, actual[ke]):
+                return False
+        else:
+            if ve != actual[ke]:
+                return False
+
+    return True
+
+
+def float_string_almost_eq(expected, actual):
+    """
+    Compares if two strings with comma-separated floats are almost equal.
+    Strings must contain floats.
+
+    >>> float_string_almost_eq('12345678900', '12345678901')
+    False
+    >>> float_string_almost_eq('12345678900.0', '12345678901.0')
+    True
+
+    >>> float_string_almost_eq('12345678900.0,-3.0', '12345678901.0,-2.9999999999')
+    True
+    """
+    if not numbers_only.match(expected) or not numbers_only.match(actual):
+        return False
+
+    expected_nums = [float(x) for x in expected.split(',')]
+    actual_nums = [float(x) for x in actual.split(',')]
+
+    if len(expected_nums) != len(actual_nums):
+        return False
+
+    for e, a in zip(expected_nums, actual_nums):
+        if abs(e - a) > abs((e+a)/2)/10e9:
+            return False
+
+    return True
+
+
+def assert_query_eq(expected, actual, fuzzy_number_compare=False):
     path_actual = path_from_query(actual)
     path_expected = path_from_query(expected)
     assert path_expected == path_actual, path_expected + '!=' + path_actual
@@ -334,9 +401,14 @@ def assert_query_eq(expected, actual):
     query_actual = set(query_to_dict(actual).items())
     query_expected = set(query_to_dict(expected).items())
 
-    assert query_expected == query_actual, '%s != %s\t%s|%s' % (
+    if fuzzy_number_compare:
+        equal = query_eq(expected, actual)
+    else:
+        equal = query_expected == query_actual
+    assert equal, '%s != %s\t%s|%s' % (
         expected, actual, query_expected - query_actual, query_actual - query_expected)
 
+
 def path_from_query(query):
     """
     >>> path_from_query('/service?foo=bar')
@@ -352,6 +424,7 @@ def path_from_query(query):
         return query.split('?', 1)[0]
     return ''
 
+
 def query_to_dict(query):
     """
     >>> sorted(query_to_dict('/service?bar=baz&foo=bizz').items())
@@ -364,13 +437,14 @@ def query_to_dict(query):
     d = {}
     if '?' in query:
         query = query.split('?', 1)[-1]
-    for key, value in cgi.parse_qsl(query):
+    for key, value in parse_qsl(query):
         d[key.lower()] = value
     return d
 
+
 def assert_url_eq(url1, url2):
-    parts1 = urlparse.urlsplit(url1)
-    parts2 = urlparse.urlsplit(url2)
+    parts1 = urlsplit(url1)
+    parts2 = urlsplit(url2)
 
     assert parts1[0] == parts2[0], '%s != %s (%s)' % (url1, url2, 'schema')
     assert parts1[1] == parts2[1], '%s != %s (%s)' % (url1, url2, 'location')
@@ -378,6 +452,7 @@ def assert_url_eq(url1, url2):
     assert query_eq(parts1[3], parts2[3]), '%s != %s (%s)' % (url1, url2, 'query')
     assert parts1[4] == parts2[4], '%s != %s (%s)' % (url1, url2, 'fragment')
 
+
 @contextmanager
 def mock_httpd(address, requests_responses, unordered=False, bbox_aware_query_comparator=False):
     if bbox_aware_query_comparator:
@@ -385,19 +460,20 @@ def mock_httpd(address, requests_responses, unordered=False, bbox_aware_query_co
     else:
         query_comparator = query_eq
     t = ThreadedStopableHTTPServer(address, requests_responses, unordered=unordered,
-        query_comparator=query_comparator)
+                                   query_comparator=query_comparator)
     t.start()
     try:
         yield
-    except:
+    except Exception:
         if not t.sucess:
-            print(str(RequestsMissmatchError(t.assertions)))
+            print(str(RequestsMismatchError(t.assertions)))
         raise
     finally:
         t.shutdown = True
-        t.join(1)
+        t.join(30)
     if not t.sucess:
-        raise RequestsMissmatchError(t.assertions)
+        raise RequestsMismatchError(t.assertions)
+
 
 @contextmanager
 def mock_single_req_httpd(address, request_handler):
@@ -405,24 +481,31 @@ def mock_single_req_httpd(address, request_handler):
     t.start()
     try:
         yield
-    except:
+    except Exception:
         if not t.sucess:
-            print(str(RequestsMissmatchError(t.assertions)))
+            print(str(RequestsMismatchError(t.assertions)))
         raise
     finally:
         t.shutdown = True
-        t.join(1)
+        t.join(30)
     if not t.sucess:
-        raise RequestsMissmatchError(t.assertions)
+        raise RequestsMismatchError(t.assertions)
 
 
 def make_wsgi_env(query_string, extra_environ={}):
-        env = {'QUERY_STRING': query_string,
-               'wsgi.url_scheme': 'http',
-               'HTTP_HOST': 'localhost',
-              }
-        env.update(extra_environ)
-        return env
+    env = {'QUERY_STRING': query_string,
+           'wsgi.url_scheme': 'http',
+           'HTTP_HOST': 'localhost',
+           }
+    env.update(extra_environ)
+    return env
+
 
 def basic_auth_value(username, password):
     return base64.b64encode(('%s:%s' % (username, password)).encode('utf-8'))
+
+
+def assert_no_cache(resp):
+    assert resp.headers["Pragma"] == "no-cache"
+    assert resp.headers["Expires"] == "-1"
+    assert resp.cache_control.no_store is True
