@@ -21,21 +21,17 @@ import codecs
 from functools import partial
 from contextlib import closing
 
+import shapely.wkt
+import shapely.geometry
+import shapely.ops
+import shapely.prepared
+from shapely.errors import ShapelyError
+
 from mapproxy.grid.tile_grid import tile_grid
 
 import logging
 log_config = logging.getLogger('mapproxy.config.coverage')
 
-try:
-    import shapely.wkt
-    import shapely.geometry
-    import shapely.ops
-    import shapely.prepared
-    from shapely.errors import ShapelyError
-    geom_support = True
-except ImportError:
-    geom_support = False
-
 
 class GeometryError(Exception):
     pass
@@ -49,11 +45,6 @@ class CoverageReadError(Exception):
     pass
 
 
-def require_geom_support():
-    if not geom_support:
-        raise ImportError('Shapely required for geometry support')
-
-
 def load_datasource(datasource, where=None):
     """
     Loads polygons from WKT text files or OGR datasources.
