@@ -22,22 +22,24 @@ import datetime
 import calendar
 from email.utils import parsedate
 from wsgiref.handlers import format_date_time
-from mapproxy import compat
+
 
 def parse_httpdate(date):
     date = parsedate(date)
     if date is None:
         return None
     if date[0] < 1970:
-        date = (date[0] + 2000,) +date[1:]
+        date = (date[0] + 2000,) + date[1:]
     return calendar.timegm(date)
 
+
 def timestamp(date):
     if isinstance(date, datetime.datetime):
         date = mktime(date.timetuple())
-    assert isinstance(date, compat.numeric_types)
+    assert isinstance(date, (float, int))
     return date
 
+
 def format_httpdate(date):
     date = timestamp(date)
     return format_date_time(date)
@@ -57,6 +59,7 @@ def timestamp_before(weeks=0, days=0, hours=0, minutes=0, seconds=0):
     before = datetime.datetime.now() - delta
     return mktime(before.timetuple())
 
+
 def timestamp_from_isodate(isodate):
     """
     >>> ts = timestamp_from_isodate('2009-06-09T10:57:00')
